@@ -1,7 +1,7 @@
 "ic1" <-
 function (p,d) 
 {
-cc <- complex(re=0, im=p/2)
+cc <- complex(real=0, imaginary=p/2)
 
 (sqrt(pi)/2)*exp(-(p^2)/4)*(1-Re(erf(cc) - erf(cc-d)))
 
